"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_asset_details_by_asset_symbol_r_data import GetAssetDetailsByAssetSymbolRData
globals()['GetAssetDetailsByAssetSymbolRData'] = GetAssetDetailsByAssetSymbolRData
from cryptoapis.model.get_asset_details_by_asset_symbol_r import GetAssetDetailsByAssetSymbolR


class TestGetAssetDetailsByAssetSymbolR(unittest.TestCase):
    """GetAssetDetailsByAssetSymbolR unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetAssetDetailsByAssetSymbolR(self):
        """Test GetAssetDetailsByAssetSymbolR"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetAssetDetailsByAssetSymbolR()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_block_details_by_block_height_from_callback_e401 import GetBlockDetailsByBlockHeightFromCallbackE401
globals()['GetBlockDetailsByBlockHeightFromCallbackE401'] = GetBlockDetailsByBlockHeightFromCallbackE401
from cryptoapis.model.get_block_details_by_block_height_from_callback401_response import GetBlockDetailsByBlockHeightFromCallback401Response


class TestGetBlockDetailsByBlockHeightFromCallback401Response(unittest.TestCase):
    """GetBlockDetailsByBlockHeightFromCallback401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetBlockDetailsByBlockHeightFromCallback401Response(self):
        """Test GetBlockDetailsByBlockHeightFromCallback401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetBlockDetailsByBlockHeightFromCallback401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cryptoapis.api_client import ApiClient, Endpoint as _Endpoint
from cryptoapis.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cryptoapis.model.convert_bitcoin_cash_address402_response import ConvertBitcoinCashAddress402Response
from cryptoapis.model.convert_bitcoin_cash_address409_response import ConvertBitcoinCashAddress409Response
from cryptoapis.model.convert_bitcoin_cash_address415_response import ConvertBitcoinCashAddress415Response
from cryptoapis.model.convert_bitcoin_cash_address422_response import ConvertBitcoinCashAddress422Response
from cryptoapis.model.convert_bitcoin_cash_address429_response import ConvertBitcoinCashAddress429Response
from cryptoapis.model.convert_bitcoin_cash_address500_response import ConvertBitcoinCashAddress500Response
from cryptoapis.model.list_supported_assets400_response import ListSupportedAssets400Response
from cryptoapis.model.list_supported_assets401_response import ListSupportedAssets401Response
from cryptoapis.model.list_supported_assets403_response import ListSupportedAssets403Response
from cryptoapis.model.list_supported_assets_r import ListSupportedAssetsR


class MetadataApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.list_supported_assets_endpoint = _Endpoint(
            settings={
                'response_type': (ListSupportedAssetsR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/market-data/assets/supported',
                'operation_id': 'list_supported_assets',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'context',
                    'asset_type',
                    'limit',
                    'offset',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'asset_type',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('asset_type',): {

                        "FIAT": "fiat",
                        "CRYPTO": "crypto"
                    },
                },
                'openapi_types': {
                    'context':
                        (str,),
                    'asset_type':
                        (str,),
                    'limit':
                        (int,),
                    'offset':
                        (int,),
                },
                'attribute_map': {
                    'context': 'context',
                    'asset_type': 'assetType',
                    'limit': 'limit',
                    'offset': 'offset',
                },
                'location_map': {
                    'context': 'query',
                    'asset_type': 'query',
                    'limit': 'query',
                    'offset': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def list_supported_assets(
        self,
        **kwargs
    ):
        """List Supported Assets  # noqa: E501

        This endpoint will return a list of supported assets. The asset could be a cryptocurrency or FIAT assets that we support. Each asset has a unique identifier - `assetId` and a unique symbol in the form of a string, e.g. \"BTC\".  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_supported_assets(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            asset_type (str): Defines the type of the supported asset. This could be either \"crypto\" or \"fiat\".. [optional]
            limit (int): Defines how many items should be returned in the response per page basis.. [optional] if omitted the server will use the default value of 50
            offset (int): The starting index of the response items, i.e. where the response should start listing the returned items.. [optional] if omitted the server will use the default value of 0
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ListSupportedAssetsR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.list_supported_assets_endpoint.call_with_http_info(**kwargs)




"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_blockchain_events_subscriptions_e400 import ListBlockchainEventsSubscriptionsE400
globals()['ListBlockchainEventsSubscriptionsE400'] = ListBlockchainEventsSubscriptionsE400
from cryptoapis.model.list_blockchain_events_subscriptions400_response import ListBlockchainEventsSubscriptions400Response


class TestListBlockchainEventsSubscriptions400Response(unittest.TestCase):
    """ListBlockchainEventsSubscriptions400Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListBlockchainEventsSubscriptions400Response(self):
        """Test ListBlockchainEventsSubscriptions400Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListBlockchainEventsSubscriptions400Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsb_vin_inner import GetWalletTransactionDetailsByTransactionIDRIBSBVinInner
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsb_vout_inner import GetWalletTransactionDetailsByTransactionIDRIBSBVoutInner
globals()['GetWalletTransactionDetailsByTransactionIDRIBSBVinInner'] = GetWalletTransactionDetailsByTransactionIDRIBSBVinInner
globals()['GetWalletTransactionDetailsByTransactionIDRIBSBVoutInner'] = GetWalletTransactionDetailsByTransactionIDRIBSBVoutInner
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsb import GetWalletTransactionDetailsByTransactionIDRIBSB


class TestGetWalletTransactionDetailsByTransactionIDRIBSB(unittest.TestCase):
    """GetWalletTransactionDetailsByTransactionIDRIBSB unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetWalletTransactionDetailsByTransactionIDRIBSB(self):
        """Test GetWalletTransactionDetailsByTransactionIDRIBSB"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetWalletTransactionDetailsByTransactionIDRIBSB()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_eip1559_fee_recommendations_e400 import GetEIP1559FeeRecommendationsE400
globals()['GetEIP1559FeeRecommendationsE400'] = GetEIP1559FeeRecommendationsE400
from cryptoapis.model.get_eip1559_fee_recommendations400_response import GetEIP1559FeeRecommendations400Response


class TestGetEIP1559FeeRecommendations400Response(unittest.TestCase):
    """GetEIP1559FeeRecommendations400Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetEIP1559FeeRecommendations400Response(self):
        """Test GetEIP1559FeeRecommendations400Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetEIP1559FeeRecommendations400Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsd_vin_inner_script_sig import GetTransactionDetailsByTransactionIDRIBSDVinInnerScriptSig
globals()['GetTransactionDetailsByTransactionIDRIBSDVinInnerScriptSig'] = GetTransactionDetailsByTransactionIDRIBSDVinInnerScriptSig
from cryptoapis.model.list_transactions_by_block_height_ribsd2_vin_inner import ListTransactionsByBlockHeightRIBSD2VinInner


class TestListTransactionsByBlockHeightRIBSD2VinInner(unittest.TestCase):
    """ListTransactionsByBlockHeightRIBSD2VinInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByBlockHeightRIBSD2VinInner(self):
        """Test ListTransactionsByBlockHeightRIBSD2VinInner"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByBlockHeightRIBSD2VinInner()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vout_inner import GetTransactionDetailsByTransactionIDRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.list_transactions_by_block_hash_ribsz_vin_inner import ListTransactionsByBlockHashRIBSZVinInner
from cryptoapis.model.list_transactions_by_block_hash_ribszv_join_split_inner import ListTransactionsByBlockHashRIBSZVJoinSplitInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVoutInner'] = GetTransactionDetailsByTransactionIDRIBSZVoutInner
globals()['ListTransactionsByBlockHashRIBSZVJoinSplitInner'] = ListTransactionsByBlockHashRIBSZVJoinSplitInner
globals()['ListTransactionsByBlockHashRIBSZVinInner'] = ListTransactionsByBlockHashRIBSZVinInner
from cryptoapis.model.list_transactions_by_block_hash_ribsz import ListTransactionsByBlockHashRIBSZ


class TestListTransactionsByBlockHashRIBSZ(unittest.TestCase):
    """ListTransactionsByBlockHashRIBSZ unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByBlockHashRIBSZ(self):
        """Test ListTransactionsByBlockHashRIBSZ"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByBlockHashRIBSZ()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.address_tokens_transaction_confirmed_data_item_mined_in_block import AddressTokensTransactionConfirmedDataItemMinedInBlock
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_token import AddressTokensTransactionConfirmedEachConfirmationToken
globals()['AddressTokensTransactionConfirmedDataItemMinedInBlock'] = AddressTokensTransactionConfirmedDataItemMinedInBlock
globals()['AddressTokensTransactionConfirmedEachConfirmationToken'] = AddressTokensTransactionConfirmedEachConfirmationToken
from cryptoapis.model.address_tokens_transaction_confirmed_each_confirmation_data_item import AddressTokensTransactionConfirmedEachConfirmationDataItem


class TestAddressTokensTransactionConfirmedEachConfirmationDataItem(unittest.TestCase):
    """AddressTokensTransactionConfirmedEachConfirmationDataItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAddressTokensTransactionConfirmedEachConfirmationDataItem(self):
        """Test AddressTokensTransactionConfirmedEachConfirmationDataItem"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AddressTokensTransactionConfirmedEachConfirmationDataItem()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_join_split_inner import GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsb import GetWalletTransactionDetailsByTransactionIDRIBSB
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsbc import GetWalletTransactionDetailsByTransactionIDRIBSBC
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsbsc import GetWalletTransactionDetailsByTransactionIDRIBSBSC
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsd import GetWalletTransactionDetailsByTransactionIDRIBSD
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsd2 import GetWalletTransactionDetailsByTransactionIDRIBSD2
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribse import GetWalletTransactionDetailsByTransactionIDRIBSE
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsec import GetWalletTransactionDetailsByTransactionIDRIBSEC
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsl import GetWalletTransactionDetailsByTransactionIDRIBSL
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsp import GetWalletTransactionDetailsByTransactionIDRIBSP
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsp_gas_price import GetWalletTransactionDetailsByTransactionIDRIBSPGasPrice
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribst import GetWalletTransactionDetailsByTransactionIDRIBST
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsz import GetWalletTransactionDetailsByTransactionIDRIBSZ
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsz_vin_inner import GetWalletTransactionDetailsByTransactionIDRIBSZVinInner
from cryptoapis.model.list_transactions_by_block_height_ribsz_vout_inner import ListTransactionsByBlockHeightRIBSZVoutInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner'] = GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetWalletTransactionDetailsByTransactionIDRIBSB'] = GetWalletTransactionDetailsByTransactionIDRIBSB
globals()['GetWalletTransactionDetailsByTransactionIDRIBSBC'] = GetWalletTransactionDetailsByTransactionIDRIBSBC
globals()['GetWalletTransactionDetailsByTransactionIDRIBSBSC'] = GetWalletTransactionDetailsByTransactionIDRIBSBSC
globals()['GetWalletTransactionDetailsByTransactionIDRIBSD'] = GetWalletTransactionDetailsByTransactionIDRIBSD
globals()['GetWalletTransactionDetailsByTransactionIDRIBSD2'] = GetWalletTransactionDetailsByTransactionIDRIBSD2
globals()['GetWalletTransactionDetailsByTransactionIDRIBSE'] = GetWalletTransactionDetailsByTransactionIDRIBSE
globals()['GetWalletTransactionDetailsByTransactionIDRIBSEC'] = GetWalletTransactionDetailsByTransactionIDRIBSEC
globals()['GetWalletTransactionDetailsByTransactionIDRIBSL'] = GetWalletTransactionDetailsByTransactionIDRIBSL
globals()['GetWalletTransactionDetailsByTransactionIDRIBSP'] = GetWalletTransactionDetailsByTransactionIDRIBSP
globals()['GetWalletTransactionDetailsByTransactionIDRIBSPGasPrice'] = GetWalletTransactionDetailsByTransactionIDRIBSPGasPrice
globals()['GetWalletTransactionDetailsByTransactionIDRIBST'] = GetWalletTransactionDetailsByTransactionIDRIBST
globals()['GetWalletTransactionDetailsByTransactionIDRIBSZ'] = GetWalletTransactionDetailsByTransactionIDRIBSZ
globals()['GetWalletTransactionDetailsByTransactionIDRIBSZVinInner'] = GetWalletTransactionDetailsByTransactionIDRIBSZVinInner
globals()['ListTransactionsByBlockHeightRIBSZVoutInner'] = ListTransactionsByBlockHeightRIBSZVoutInner
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribs import GetWalletTransactionDetailsByTransactionIDRIBS


class TestGetWalletTransactionDetailsByTransactionIDRIBS(unittest.TestCase):
    """GetWalletTransactionDetailsByTransactionIDRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetWalletTransactionDetailsByTransactionIDRIBS(self):
        """Test GetWalletTransactionDetailsByTransactionIDRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetWalletTransactionDetailsByTransactionIDRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.estimate_gas_limit_e403 import EstimateGasLimitE403
globals()['EstimateGasLimitE403'] = EstimateGasLimitE403
from cryptoapis.model.estimate_gas_limit403_response import EstimateGasLimit403Response


class TestEstimateGasLimit403Response(unittest.TestCase):
    """EstimateGasLimit403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEstimateGasLimit403Response(self):
        """Test EstimateGasLimit403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EstimateGasLimit403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsb import GetTransactionDetailsByTransactionIDFromCallbackRIBSB
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsbc import GetTransactionDetailsByTransactionIDFromCallbackRIBSBC
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsbsc import GetTransactionDetailsByTransactionIDFromCallbackRIBSBSC
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsd import GetTransactionDetailsByTransactionIDFromCallbackRIBSD
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsd2 import GetTransactionDetailsByTransactionIDFromCallbackRIBSD2
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribse import GetTransactionDetailsByTransactionIDFromCallbackRIBSE
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsec import GetTransactionDetailsByTransactionIDFromCallbackRIBSEC
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsl import GetTransactionDetailsByTransactionIDFromCallbackRIBSL
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsp import GetTransactionDetailsByTransactionIDFromCallbackRIBSP
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribst import GetTransactionDetailsByTransactionIDFromCallbackRIBST
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribst_bandwidth_used import GetTransactionDetailsByTransactionIDFromCallbackRIBSTBandwidthUsed
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribst_energy_used import GetTransactionDetailsByTransactionIDFromCallbackRIBSTEnergyUsed
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsx import GetTransactionDetailsByTransactionIDFromCallbackRIBSX
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsx_value import GetTransactionDetailsByTransactionIDFromCallbackRIBSXValue
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsz import GetTransactionDetailsByTransactionIDFromCallbackRIBSZ
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsz2 import GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribsz_vout_inner import GetTransactionDetailsByTransactionIDFromCallbackRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vin_inner import GetTransactionDetailsByTransactionIDRIBSZVinInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_join_split_inner import GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_offer import GetXRPRippleTransactionDetailsByTransactionIDRIOffer
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_receive import GetXRPRippleTransactionDetailsByTransactionIDRIReceive
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSB'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSB
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSBC'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSBC
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSBSC'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSBSC
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSD'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSD
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSD2'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSD2
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSE'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSE
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSEC'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSEC
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSL'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSL
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSP'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSP
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBST'] = GetTransactionDetailsByTransactionIDFromCallbackRIBST
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSTBandwidthUsed'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSTBandwidthUsed
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSTEnergyUsed'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSTEnergyUsed
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSX'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSX
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSXValue'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSXValue
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSZ'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSZ
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSZ2
globals()['GetTransactionDetailsByTransactionIDFromCallbackRIBSZVoutInner'] = GetTransactionDetailsByTransactionIDFromCallbackRIBSZVoutInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner'] = GetTransactionDetailsByTransactionIDRIBSZVJoinSplitInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVinInner'] = GetTransactionDetailsByTransactionIDRIBSZVinInner
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIOffer'] = GetXRPRippleTransactionDetailsByTransactionIDRIOffer
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIReceive'] = GetXRPRippleTransactionDetailsByTransactionIDRIReceive
from cryptoapis.model.get_transaction_details_by_transaction_id_from_callback_ribs import GetTransactionDetailsByTransactionIDFromCallbackRIBS


class TestGetTransactionDetailsByTransactionIDFromCallbackRIBS(unittest.TestCase):
    """GetTransactionDetailsByTransactionIDFromCallbackRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetTransactionDetailsByTransactionIDFromCallbackRIBS(self):
        """Test GetTransactionDetailsByTransactionIDFromCallbackRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetTransactionDetailsByTransactionIDFromCallbackRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsd_vout_inner import GetTransactionDetailsByTransactionIDRIBSDVoutInner
from cryptoapis.model.list_confirmed_transactions_by_address_ribsd_vin_inner import ListConfirmedTransactionsByAddressRIBSDVinInner
globals()['GetTransactionDetailsByTransactionIDRIBSDVoutInner'] = GetTransactionDetailsByTransactionIDRIBSDVoutInner
globals()['ListConfirmedTransactionsByAddressRIBSDVinInner'] = ListConfirmedTransactionsByAddressRIBSDVinInner
from cryptoapis.model.list_confirmed_transactions_by_address_and_time_range_ribsd import ListConfirmedTransactionsByAddressAndTimeRangeRIBSD


class TestListConfirmedTransactionsByAddressAndTimeRangeRIBSD(unittest.TestCase):
    """ListConfirmedTransactionsByAddressAndTimeRangeRIBSD unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListConfirmedTransactionsByAddressAndTimeRangeRIBSD(self):
        """Test ListConfirmedTransactionsByAddressAndTimeRangeRIBSD"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListConfirmedTransactionsByAddressAndTimeRangeRIBSD()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_zilliqa_transactions_by_block_height_e401 import ListZilliqaTransactionsByBlockHeightE401
globals()['ListZilliqaTransactionsByBlockHeightE401'] = ListZilliqaTransactionsByBlockHeightE401
from cryptoapis.model.list_zilliqa_transactions_by_block_height401_response import ListZilliqaTransactionsByBlockHeight401Response


class TestListZilliqaTransactionsByBlockHeight401Response(unittest.TestCase):
    """ListZilliqaTransactionsByBlockHeight401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListZilliqaTransactionsByBlockHeight401Response(self):
        """Test ListZilliqaTransactionsByBlockHeight401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListZilliqaTransactionsByBlockHeight401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsd2_vin_inner import ListUnconfirmedTransactionsByAddressRIBSD2VinInner
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsd2_vout_inner import ListUnconfirmedTransactionsByAddressRIBSD2VoutInner
globals()['ListUnconfirmedTransactionsByAddressRIBSD2VinInner'] = ListUnconfirmedTransactionsByAddressRIBSD2VinInner
globals()['ListUnconfirmedTransactionsByAddressRIBSD2VoutInner'] = ListUnconfirmedTransactionsByAddressRIBSD2VoutInner
from cryptoapis.model.list_unconfirmed_transactions_by_address_ribsd2 import ListUnconfirmedTransactionsByAddressRIBSD2


class TestListUnconfirmedTransactionsByAddressRIBSD2(unittest.TestCase):
    """ListUnconfirmedTransactionsByAddressRIBSD2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListUnconfirmedTransactionsByAddressRIBSD2(self):
        """Test ListUnconfirmedTransactionsByAddressRIBSD2"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListUnconfirmedTransactionsByAddressRIBSD2()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cryptoapis.api_client import ApiClient, Endpoint as _Endpoint
from cryptoapis.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cryptoapis.model.convert_bitcoin_cash_address402_response import ConvertBitcoinCashAddress402Response
from cryptoapis.model.convert_bitcoin_cash_address409_response import ConvertBitcoinCashAddress409Response
from cryptoapis.model.convert_bitcoin_cash_address415_response import ConvertBitcoinCashAddress415Response
from cryptoapis.model.convert_bitcoin_cash_address422_response import ConvertBitcoinCashAddress422Response
from cryptoapis.model.convert_bitcoin_cash_address429_response import ConvertBitcoinCashAddress429Response
from cryptoapis.model.convert_bitcoin_cash_address500_response import ConvertBitcoinCashAddress500Response
from cryptoapis.model.get_asset_details_by_asset_id400_response import GetAssetDetailsByAssetID400Response
from cryptoapis.model.get_asset_details_by_asset_id401_response import GetAssetDetailsByAssetID401Response
from cryptoapis.model.get_asset_details_by_asset_id403_response import GetAssetDetailsByAssetID403Response
from cryptoapis.model.get_asset_details_by_asset_idr import GetAssetDetailsByAssetIDR
from cryptoapis.model.get_asset_details_by_asset_symbol400_response import GetAssetDetailsByAssetSymbol400Response
from cryptoapis.model.get_asset_details_by_asset_symbol401_response import GetAssetDetailsByAssetSymbol401Response
from cryptoapis.model.get_asset_details_by_asset_symbol403_response import GetAssetDetailsByAssetSymbol403Response
from cryptoapis.model.get_asset_details_by_asset_symbol_r import GetAssetDetailsByAssetSymbolR


class AssetsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_asset_details_by_asset_id_endpoint = _Endpoint(
            settings={
                'response_type': (GetAssetDetailsByAssetIDR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/market-data/assets/assetId/{assetId}',
                'operation_id': 'get_asset_details_by_asset_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'asset_id',
                    'context',
                ],
                'required': [
                    'asset_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'asset_id':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'asset_id': 'assetId',
                    'context': 'context',
                },
                'location_map': {
                    'asset_id': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_asset_details_by_asset_symbol_endpoint = _Endpoint(
            settings={
                'response_type': (GetAssetDetailsByAssetSymbolR,),
                'auth': [
                    'ApiKey'
                ],
                'endpoint_path': '/market-data/assets/{assetSymbol}',
                'operation_id': 'get_asset_details_by_asset_symbol',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'asset_symbol',
                    'context',
                ],
                'required': [
                    'asset_symbol',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'asset_symbol':
                        (str,),
                    'context':
                        (str,),
                },
                'attribute_map': {
                    'asset_symbol': 'assetSymbol',
                    'context': 'context',
                },
                'location_map': {
                    'asset_symbol': 'path',
                    'context': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def get_asset_details_by_asset_id(
        self,
        asset_id,
        **kwargs
    ):
        """Get Asset Details By Asset ID  # noqa: E501

        Through this endpoint users can obtain information on assets by `assetId`.    The details returned could include information on the latest rate and rate fluctuation of different periods of time - 24 hours, a week, one hour, the encoding of the logo, and more.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_asset_details_by_asset_id(asset_id, async_req=True)
        >>> result = thread.get()

        Args:
            asset_id (str): Defines the unique ID of the specific asset.

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetAssetDetailsByAssetIDR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['asset_id'] = \
            asset_id
        return self.get_asset_details_by_asset_id_endpoint.call_with_http_info(**kwargs)

    def get_asset_details_by_asset_symbol(
        self,
        asset_symbol,
        **kwargs
    ):
        """Get Asset Details By Asset Symbol  # noqa: E501

        Through this endpoint users can obtain information on assets by asset symbol.    The details returned could include information on the latest rate and rate fluctuation of different periods of time - 24 hours, a week, one hour, the encoding of the logo, and more.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_asset_details_by_asset_symbol(asset_symbol, async_req=True)
        >>> result = thread.get()

        Args:
            asset_symbol (str): Specifies the asset's unique symbol in the Crypto APIs listings.

        Keyword Args:
            context (str): In batch situations the user can use the context to correlate responses with requests. This property is present regardless of whether the response was successful or returned as an error. `context` is specified by the user.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetAssetDetailsByAssetSymbolR
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['asset_symbol'] = \
            asset_symbol
        return self.get_asset_details_by_asset_symbol_endpoint.call_with_http_info(**kwargs)




"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_block_details_by_block_hash_from_callback_e401 import GetBlockDetailsByBlockHashFromCallbackE401
globals()['GetBlockDetailsByBlockHashFromCallbackE401'] = GetBlockDetailsByBlockHashFromCallbackE401
from cryptoapis.model.get_block_details_by_block_hash_from_callback401_response import GetBlockDetailsByBlockHashFromCallback401Response


class TestGetBlockDetailsByBlockHashFromCallback401Response(unittest.TestCase):
    """GetBlockDetailsByBlockHashFromCallback401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetBlockDetailsByBlockHashFromCallback401Response(self):
        """Test GetBlockDetailsByBlockHashFromCallback401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetBlockDetailsByBlockHashFromCallback401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_token_details_by_contract_address_e401 import GetTokenDetailsByContractAddressE401
globals()['GetTokenDetailsByContractAddressE401'] = GetTokenDetailsByContractAddressE401
from cryptoapis.model.get_token_details_by_contract_address401_response import GetTokenDetailsByContractAddress401Response


class TestGetTokenDetailsByContractAddress401Response(unittest.TestCase):
    """GetTokenDetailsByContractAddress401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetTokenDetailsByContractAddress401Response(self):
        """Test GetTokenDetailsByContractAddress401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetTokenDetailsByContractAddress401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsz_vout_inner import GetTransactionDetailsByTransactionIDRIBSZVoutInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_output_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
from cryptoapis.model.get_transaction_details_by_transaction_idribszv_shielded_spend_inner import GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
from cryptoapis.model.list_confirmed_transactions_by_address_ribsb import ListConfirmedTransactionsByAddressRIBSB
from cryptoapis.model.list_confirmed_transactions_by_address_ribsbc import ListConfirmedTransactionsByAddressRIBSBC
from cryptoapis.model.list_confirmed_transactions_by_address_ribsbsc import ListConfirmedTransactionsByAddressRIBSBSC
from cryptoapis.model.list_confirmed_transactions_by_address_ribsbsc_gas_price import ListConfirmedTransactionsByAddressRIBSBSCGasPrice
from cryptoapis.model.list_confirmed_transactions_by_address_ribsd import ListConfirmedTransactionsByAddressRIBSD
from cryptoapis.model.list_confirmed_transactions_by_address_ribsd2 import ListConfirmedTransactionsByAddressRIBSD2
from cryptoapis.model.list_confirmed_transactions_by_address_ribse import ListConfirmedTransactionsByAddressRIBSE
from cryptoapis.model.list_confirmed_transactions_by_address_ribsec import ListConfirmedTransactionsByAddressRIBSEC
from cryptoapis.model.list_confirmed_transactions_by_address_ribsl import ListConfirmedTransactionsByAddressRIBSL
from cryptoapis.model.list_confirmed_transactions_by_address_ribsz import ListConfirmedTransactionsByAddressRIBSZ
from cryptoapis.model.list_confirmed_transactions_by_address_ribsz_vin_inner import ListConfirmedTransactionsByAddressRIBSZVinInner
from cryptoapis.model.list_confirmed_transactions_by_address_ribszv_join_split_inner import ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedOutputInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner'] = GetTransactionDetailsByTransactionIDRIBSZVShieldedSpendInner
globals()['GetTransactionDetailsByTransactionIDRIBSZVoutInner'] = GetTransactionDetailsByTransactionIDRIBSZVoutInner
globals()['ListConfirmedTransactionsByAddressRIBSB'] = ListConfirmedTransactionsByAddressRIBSB
globals()['ListConfirmedTransactionsByAddressRIBSBC'] = ListConfirmedTransactionsByAddressRIBSBC
globals()['ListConfirmedTransactionsByAddressRIBSBSC'] = ListConfirmedTransactionsByAddressRIBSBSC
globals()['ListConfirmedTransactionsByAddressRIBSBSCGasPrice'] = ListConfirmedTransactionsByAddressRIBSBSCGasPrice
globals()['ListConfirmedTransactionsByAddressRIBSD'] = ListConfirmedTransactionsByAddressRIBSD
globals()['ListConfirmedTransactionsByAddressRIBSD2'] = ListConfirmedTransactionsByAddressRIBSD2
globals()['ListConfirmedTransactionsByAddressRIBSE'] = ListConfirmedTransactionsByAddressRIBSE
globals()['ListConfirmedTransactionsByAddressRIBSEC'] = ListConfirmedTransactionsByAddressRIBSEC
globals()['ListConfirmedTransactionsByAddressRIBSL'] = ListConfirmedTransactionsByAddressRIBSL
globals()['ListConfirmedTransactionsByAddressRIBSZ'] = ListConfirmedTransactionsByAddressRIBSZ
globals()['ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner'] = ListConfirmedTransactionsByAddressRIBSZVJoinSplitInner
globals()['ListConfirmedTransactionsByAddressRIBSZVinInner'] = ListConfirmedTransactionsByAddressRIBSZVinInner
from cryptoapis.model.list_confirmed_transactions_by_address_ribs import ListConfirmedTransactionsByAddressRIBS


class TestListConfirmedTransactionsByAddressRIBS(unittest.TestCase):
    """ListConfirmedTransactionsByAddressRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListConfirmedTransactionsByAddressRIBS(self):
        """Test ListConfirmedTransactionsByAddressRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListConfirmedTransactionsByAddressRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idri_fee import GetZilliqaTransactionDetailsByTransactionIDRIFee
from cryptoapis.model.list_zilliqa_transactions_by_address_ri_recipients_inner import ListZilliqaTransactionsByAddressRIRecipientsInner
from cryptoapis.model.list_zilliqa_transactions_by_address_ri_senders_inner import ListZilliqaTransactionsByAddressRISendersInner
globals()['GetZilliqaTransactionDetailsByTransactionIDRIFee'] = GetZilliqaTransactionDetailsByTransactionIDRIFee
globals()['ListZilliqaTransactionsByAddressRIRecipientsInner'] = ListZilliqaTransactionsByAddressRIRecipientsInner
globals()['ListZilliqaTransactionsByAddressRISendersInner'] = ListZilliqaTransactionsByAddressRISendersInner
from cryptoapis.model.list_zilliqa_transactions_by_address_ri import ListZilliqaTransactionsByAddressRI


class TestListZilliqaTransactionsByAddressRI(unittest.TestCase):
    """ListZilliqaTransactionsByAddressRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListZilliqaTransactionsByAddressRI(self):
        """Test ListZilliqaTransactionsByAddressRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListZilliqaTransactionsByAddressRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_transactions_by_block_hash_ribsbc_vin_inner import ListTransactionsByBlockHashRIBSBCVinInner
from cryptoapis.model.list_transactions_by_block_hash_ribsbc_vout_inner import ListTransactionsByBlockHashRIBSBCVoutInner
globals()['ListTransactionsByBlockHashRIBSBCVinInner'] = ListTransactionsByBlockHashRIBSBCVinInner
globals()['ListTransactionsByBlockHashRIBSBCVoutInner'] = ListTransactionsByBlockHashRIBSBCVoutInner
from cryptoapis.model.list_transactions_by_block_hash_ribsbc import ListTransactionsByBlockHashRIBSBC


class TestListTransactionsByBlockHashRIBSBC(unittest.TestCase):
    """ListTransactionsByBlockHashRIBSBC unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByBlockHashRIBSBC(self):
        """Test ListTransactionsByBlockHashRIBSBC"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByBlockHashRIBSBC()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.derive_and_sync_new_change_addresses_e403 import DeriveAndSyncNewChangeAddressesE403
globals()['DeriveAndSyncNewChangeAddressesE403'] = DeriveAndSyncNewChangeAddressesE403
from cryptoapis.model.derive_and_sync_new_change_addresses403_response import DeriveAndSyncNewChangeAddresses403Response


class TestDeriveAndSyncNewChangeAddresses403Response(unittest.TestCase):
    """DeriveAndSyncNewChangeAddresses403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDeriveAndSyncNewChangeAddresses403Response(self):
        """Test DeriveAndSyncNewChangeAddresses403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DeriveAndSyncNewChangeAddresses403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_fee_recommendations_e403 import GetFeeRecommendationsE403
globals()['GetFeeRecommendationsE403'] = GetFeeRecommendationsE403
from cryptoapis.model.get_fee_recommendations403_response import GetFeeRecommendations403Response


class TestGetFeeRecommendations403Response(unittest.TestCase):
    """GetFeeRecommendations403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetFeeRecommendations403Response(self):
        """Test GetFeeRecommendations403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetFeeRecommendations403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.create_coins_transaction_from_address_for_whole_amount_e403 import CreateCoinsTransactionFromAddressForWholeAmountE403
globals()['CreateCoinsTransactionFromAddressForWholeAmountE403'] = CreateCoinsTransactionFromAddressForWholeAmountE403
from cryptoapis.model.create_coins_transaction_from_address_for_whole_amount403_response import CreateCoinsTransactionFromAddressForWholeAmount403Response


class TestCreateCoinsTransactionFromAddressForWholeAmount403Response(unittest.TestCase):
    """CreateCoinsTransactionFromAddressForWholeAmount403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateCoinsTransactionFromAddressForWholeAmount403Response(self):
        """Test CreateCoinsTransactionFromAddressForWholeAmount403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateCoinsTransactionFromAddressForWholeAmount403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_ide401 import GetZilliqaTransactionDetailsByTransactionIDE401
globals()['GetZilliqaTransactionDetailsByTransactionIDE401'] = GetZilliqaTransactionDetailsByTransactionIDE401
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_id401_response import GetZilliqaTransactionDetailsByTransactionID401Response


class TestGetZilliqaTransactionDetailsByTransactionID401Response(unittest.TestCase):
    """GetZilliqaTransactionDetailsByTransactionID401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetZilliqaTransactionDetailsByTransactionID401Response(self):
        """Test GetZilliqaTransactionDetailsByTransactionID401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetZilliqaTransactionDetailsByTransactionID401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.invalid_request_body_structure import InvalidRequestBodyStructure
globals()['InvalidRequestBodyStructure'] = InvalidRequestBodyStructure
from cryptoapis.model.convert_bitcoin_cash_address422_response import ConvertBitcoinCashAddress422Response


class TestConvertBitcoinCashAddress422Response(unittest.TestCase):
    """ConvertBitcoinCashAddress422Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testConvertBitcoinCashAddress422Response(self):
        """Test ConvertBitcoinCashAddress422Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ConvertBitcoinCashAddress422Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_wallet_asset_details_ri_confirmed_balance import GetWalletAssetDetailsRIConfirmedBalance
from cryptoapis.model.get_wallet_asset_details_ri_fungible_tokens_inner import GetWalletAssetDetailsRIFungibleTokensInner
from cryptoapis.model.get_wallet_asset_details_ri_non_fungible_tokens_inner import GetWalletAssetDetailsRINonFungibleTokensInner
from cryptoapis.model.get_wallet_asset_details_ri_recieved_confirmed_amount import GetWalletAssetDetailsRIRecievedConfirmedAmount
from cryptoapis.model.get_wallet_asset_details_ri_sent_confirmed_amount import GetWalletAssetDetailsRISentConfirmedAmount
globals()['GetWalletAssetDetailsRIConfirmedBalance'] = GetWalletAssetDetailsRIConfirmedBalance
globals()['GetWalletAssetDetailsRIFungibleTokensInner'] = GetWalletAssetDetailsRIFungibleTokensInner
globals()['GetWalletAssetDetailsRINonFungibleTokensInner'] = GetWalletAssetDetailsRINonFungibleTokensInner
globals()['GetWalletAssetDetailsRIRecievedConfirmedAmount'] = GetWalletAssetDetailsRIRecievedConfirmedAmount
globals()['GetWalletAssetDetailsRISentConfirmedAmount'] = GetWalletAssetDetailsRISentConfirmedAmount
from cryptoapis.model.get_wallet_asset_details_ri import GetWalletAssetDetailsRI


class TestGetWalletAssetDetailsRI(unittest.TestCase):
    """GetWalletAssetDetailsRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetWalletAssetDetailsRI(self):
        """Test GetWalletAssetDetailsRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetWalletAssetDetailsRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsbc_vin_inner import GetWalletTransactionDetailsByTransactionIDRIBSBCVinInner
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsbc_vout_inner import GetWalletTransactionDetailsByTransactionIDRIBSBCVoutInner
globals()['GetWalletTransactionDetailsByTransactionIDRIBSBCVinInner'] = GetWalletTransactionDetailsByTransactionIDRIBSBCVinInner
globals()['GetWalletTransactionDetailsByTransactionIDRIBSBCVoutInner'] = GetWalletTransactionDetailsByTransactionIDRIBSBCVoutInner
from cryptoapis.model.get_wallet_transaction_details_by_transaction_idribsbc import GetWalletTransactionDetailsByTransactionIDRIBSBC


class TestGetWalletTransactionDetailsByTransactionIDRIBSBC(unittest.TestCase):
    """GetWalletTransactionDetailsByTransactionIDRIBSBC unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetWalletTransactionDetailsByTransactionIDRIBSBC(self):
        """Test GetWalletTransactionDetailsByTransactionIDRIBSBC"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetWalletTransactionDetailsByTransactionIDRIBSBC()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.create_fungible_token_transaction_request_from_address_without_fee_priority_e401 import CreateFungibleTokenTransactionRequestFromAddressWithoutFeePriorityE401
globals()['CreateFungibleTokenTransactionRequestFromAddressWithoutFeePriorityE401'] = CreateFungibleTokenTransactionRequestFromAddressWithoutFeePriorityE401
from cryptoapis.model.create_fungible_token_transaction_request_from_address_without_fee_priority401_response import CreateFungibleTokenTransactionRequestFromAddressWithoutFeePriority401Response


class TestCreateFungibleTokenTransactionRequestFromAddressWithoutFeePriority401Response(unittest.TestCase):
    """CreateFungibleTokenTransactionRequestFromAddressWithoutFeePriority401Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateFungibleTokenTransactionRequestFromAddressWithoutFeePriority401Response(self):
        """Test CreateFungibleTokenTransactionRequestFromAddressWithoutFeePriority401Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateFungibleTokenTransactionRequestFromAddressWithoutFeePriority401Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.convert_bitcoin_cash_address_e403 import ConvertBitcoinCashAddressE403
globals()['ConvertBitcoinCashAddressE403'] = ConvertBitcoinCashAddressE403
from cryptoapis.model.convert_bitcoin_cash_address403_response import ConvertBitcoinCashAddress403Response


class TestConvertBitcoinCashAddress403Response(unittest.TestCase):
    """ConvertBitcoinCashAddress403Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testConvertBitcoinCashAddress403Response(self):
        """Test ConvertBitcoinCashAddress403Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ConvertBitcoinCashAddress403Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_transactions_by_block_hash_ri_fee import ListTransactionsByBlockHashRIFee
from cryptoapis.model.list_transactions_by_block_hash_ri_recipients_inner import ListTransactionsByBlockHashRIRecipientsInner
from cryptoapis.model.list_transactions_by_block_hash_ri_senders_inner import ListTransactionsByBlockHashRISendersInner
from cryptoapis.model.list_transactions_by_block_hash_ribs import ListTransactionsByBlockHashRIBS
globals()['ListTransactionsByBlockHashRIBS'] = ListTransactionsByBlockHashRIBS
globals()['ListTransactionsByBlockHashRIFee'] = ListTransactionsByBlockHashRIFee
globals()['ListTransactionsByBlockHashRIRecipientsInner'] = ListTransactionsByBlockHashRIRecipientsInner
globals()['ListTransactionsByBlockHashRISendersInner'] = ListTransactionsByBlockHashRISendersInner
from cryptoapis.model.list_transactions_by_block_hash_ri import ListTransactionsByBlockHashRI


class TestListTransactionsByBlockHashRI(unittest.TestCase):
    """ListTransactionsByBlockHashRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByBlockHashRI(self):
        """Test ListTransactionsByBlockHashRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByBlockHashRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    CryptoAPIs

    Crypto APIs is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2021-03-20
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.create_coins_transaction_request_from_address_ri import CreateCoinsTransactionRequestFromAddressRI
globals()['CreateCoinsTransactionRequestFromAddressRI'] = CreateCoinsTransactionRequestFromAddressRI
from cryptoapis.model.create_coins_transaction_request_from_address_r_data import CreateCoinsTransactionRequestFromAddressRData


class TestCreateCoinsTransactionRequestFromAddressRData(unittest.TestCase):
    """CreateCoinsTransactionRequestFromAddressRData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateCoinsTransactionRequestFromAddressRData(self):
        """Test CreateCoinsTransactionRequestFromAddressRData"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateCoinsTransactionRequestFromAddressRData()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
